@@ -22,6 +22,7 @@ import math
 import re
 from Bio import SeqIO
 from io import StringIO
+import random
 
 import fdog.libs.fasta as fasta_fn
 import fdog.libs.output as output_fn
@@ -140,7 +141,12 @@ def calc_aln_score(fa1, fa2, aln_strategy = 'local', debugCore = False):
     Return dictionary {gene_id:aln_score}
     """
     fdog_path = os.path.realpath(__file__).replace('/libs/alignment.py','')
-    fasta36_options = '%s %s -s BP62 -m 9 -d 0 -z -1 -E 100' % (fa1, fa2)
+    fa1_filename = fa1.split("/")[-1]
+    fa2_filename = fa2.split("/")[-1]
+    os.symlink(fa1, fa1_filename)
+    if not fa2_filename == fa1_filename:
+        os.symlink(fa2, fa2_filename)
+    fasta36_options = f'{fa1_filename} {fa2_filename} -s BP62 -m 9 -d 0 -z -1 -E 100'
     fdog_path = os.path.realpath(__file__).replace('/libs/alignment.py','')
     fasta36_bin = check_fasta36_executable(fdog_path)
     if aln_strategy == 'global':
@@ -173,4 +179,7 @@ def calc_aln_score(fa1, fa2, aln_strategy = 'local', debugCore = False):
                 if re.search('\(\s+\d+\)', l):
                     l = re.sub(r'\(\s+','(', l)
                 aln_score[gene_id] = aln_score[gene_id] + int(l.split()[2])
+    os.remove(fa1_filename)
+    if not fa2_filename == fa1_filename:
+        os.remove(fa2_filename)
     return(aln_score)
