@@ -234,6 +234,7 @@ def main():
     addtionalIO.add_argument('--append', help='Append the output to existing output files', action='store_true', default=False)
     addtionalIO.add_argument('--force', help='Overwrite existing ortholog search output files', action='store_true', default=False)
     addtionalIO.add_argument('--forceCore', help='Overwrite existing core set of your sequence', action='store_true', default=False)
+    addtionalIO.add_argument('--notAddingTaxa', help='Do not add all search taxa to phyloprofile output', action='store_true', default=False)
     addtionalIO.add_argument('--noCleanup', help='Temporary output will NOT be deleted. Default: False', action='store_true', default=False)
     addtionalIO.add_argument('--keep', help='Keep output of individual seed sequence. Default: False', action='store_true', default=False)
     addtionalIO.add_argument('--debug', help='Set this flag to obtain more detailed information about the ortholog search progress', action='store_true', default=False)
@@ -310,6 +311,7 @@ def main():
     debug = args.debug
     debugCore = args.debugCore
     silentOff = args.silentOff
+    notAddingTaxa = args.notAddingTaxa
 
     # others
     aligner = args.aligner
@@ -320,12 +322,27 @@ def main():
 
     begin = time.time()
     ##### Check and group parameters
+    print('##### PREPARING & CHECKING #####')
     (inFol, hmmpath, corepath, searchpath, annopath) = prepare_fn.check_input(
                     [inFol, refspec, outpath, hmmpath,
                     corepath, searchpath, annopath, pathFile])
     pathArgs = [outpath, hmmpath, corepath, searchpath, annopath]
     prepare_fn.check_blast_version(corepath, refspec)
 
+    (invalid_minDist, invalid_maxDist, suggested_minRank, suggested_maxRank) = prepare_fn.check_ranks_core_taxa(corepath, refspec, minDist, maxDist)
+    if len(invalid_minDist) > 0 or len(invalid_maxDist) > 0:
+        if len(invalid_minDist) > 0:
+            print(f'Invalid {minDist} (--minDist) for:\t{", ".join(invalid_minDist)}')
+        if len(invalid_maxDist) > 0:
+            print(f'Invalid {maxDist} (--maxDist) for:\t{", ".join(invalid_maxDist)}')
+        if not minDist == "genus" and not maxDist == "kingdom":
+            print(f'Please consider setting --minDist and --maxDist with these valid ranks:\n--minDist {suggested_minRank} --maxDist {suggested_maxRank}')
+            sys.exit()
+        else:
+            print(f'WARNING: --minDist and --maxDist will be automatically changed to {suggested_minRank} and {suggested_maxRank}')
+            minDist = suggested_minRank
+            maxDist = suggested_maxRank
+
     if not fasOff:
         check_fas = fas_fn.check_fas_executable()
         if check_fas == 0:
@@ -343,7 +360,7 @@ def main():
 
     ##### DO CORE COMPILATION
     if reuseCore == False:
-        print('Starting compiling core orthologs...')
+        print('##### COMPILING CORE ORTHOLOG GROUPS #####')
         start = time.time()
         coreArgs = [minDist, maxDist, coreSize, coreTaxa, distDeviation,
                     alnStrategy, fasOff]
@@ -369,7 +386,7 @@ def main():
     ##### DO ORTHOLOG SEARCH USING HMM (HAMSTR)
     finalFa = '%s/%s.extended.fa' % (outpath, jobName)
     if not coreOnly:
-        print('Searching orthologs...')
+        print('##### SEARCHING ORTHOLOGS #####')
         start = time.time()
         if not os.path.exists(finalFa) or force == True:
             ### get list of search taxa
@@ -417,6 +434,7 @@ def main():
 
         ##### DO FINAL FAS CALCULATION
         if not fasOff:
+            print('##### CALCULATING FAS SCORES #####')
             try:
                 fasVersion = subprocess.run(['fas.run --version'], shell = True, capture_output = True, check = True)
             except:
@@ -430,6 +448,14 @@ def main():
         else:
             output_fn.hamstr_2_profile(finalFa)
 
+        ##### ADD ALL SEARCH TAXA INTO PhyloProfile OUTPUT
+        if not notAddingTaxa:
+            pp_file = f'{outpath}/{jobName}.phyloprofile'
+            if not searchTaxa:
+                tmp = general_fn.read_dir(searchpath)
+                searchTaxa = ','.join(tmp)
+            output_fn.add_all_taxa(pp_file, searchTaxa)
+
         end = time.time()
         print('==> fdogs.run finished in ' + '{:5.3f}s'.format(end - begin))
 
