@@ -23,6 +23,7 @@ from ete3 import NCBITaxa
 from pkg_resources import get_distribution
 import time
 
+import fdog.libs.zzz as general_fn
 import fdog.libs.preparation as prepare_fn
 import fdog.libs.orthosearch as ortho_fn
 import fdog.libs.corecompile as core_fn
@@ -105,6 +106,7 @@ def main():
     addtionalIO.add_argument('--append', help='Append the output to existing output files', action='store_true', default=False)
     addtionalIO.add_argument('--force', help='Overwrite existing ortholog search output files', action='store_true', default=False)
     addtionalIO.add_argument('--forceCore', help='Overwrite existing core set of your sequence', action='store_true', default=False)
+    addtionalIO.add_argument('--notAddingTaxa', help='Do not add all search taxa to phyloprofile output', action='store_true', default=False)
     addtionalIO.add_argument('--noCleanup', help='Temporary output will NOT be deleted. Default: False', action='store_true', default=False)
     addtionalIO.add_argument('--debug', help='Set this flag to obtain more detailed information about the ortholog search progress', action='store_true', default=False)
     addtionalIO.add_argument('--debugCore', help='Set this flag to obtain more detailed information about the core compilation actions', action='store_true', default=False)
@@ -179,6 +181,7 @@ def main():
     debug = args.debug
     debugCore = args.debugCore
     silentOff = args.silentOff
+    notAddingTaxa = args.notAddingTaxa
 
     # others
     aligner = args.aligner
@@ -189,6 +192,7 @@ def main():
 
     begin = time.time()
     ##### Check and group parameters
+    print('##### PREPARING & CHECKING #####')
     if seqFile == 'infile.fa':
         fdogPath = os.path.realpath(__file__).replace('/runSingle.py','')
         seqFile = '%s/data/infile.fa' % fdogPath
@@ -200,6 +204,20 @@ def main():
 
     prepare_fn.check_blast_version(corepath, refspec)
 
+    (invalid_minDist, invalid_maxDist, suggested_minRank, suggested_maxRank) = prepare_fn.check_ranks_core_taxa(corepath, refspec, minDist, maxDist)
+    if len(invalid_minDist) > 0 or len(invalid_maxDist) > 0:
+        if len(invalid_minDist) > 0:
+            print(f'Invalid {minDist} (--minDist) for:\t{", ".join(invalid_minDist)}')
+        if len(invalid_maxDist) > 0:
+            print(f'Invalid {maxDist} (--maxDist) for:\t{", ".join(invalid_maxDist)}')
+        if not minDist == "genus" and not maxDist == "kingdom":
+            print(f'Please consider setting --minDist and --maxDist with these valid ranks:\n--minDist {suggested_minRank} --maxDist {suggested_maxRank}')
+            sys.exit()
+        else:
+            print(f'WARNING: --minDist and --maxDist will be automatically changed to {suggested_minRank} and {suggested_maxRank}')
+            minDist = suggested_minRank
+            maxDist = suggested_maxRank
+
     if not fasOff:
         check_fas = fas_fn.check_fas_executable()
         if check_fas == 0:
@@ -211,7 +229,7 @@ def main():
         seed_id = prepare_fn.get_seed_id_from_fa(core_fa, refspec)
     else:
         seed_id = prepare_fn.identify_seed_id(seqFile, refspec, corepath, debug, silentOff)
-    print('Identified seed ID: %s' % seed_id)
+    print('==> Identified seed ID: %s' % seed_id)
 
     ##### DO CORE COMPILATION
     # start = time.time()
@@ -221,7 +239,7 @@ def main():
                     lowComplexityFilter, evalHmmer/10, coreHitLimit,
                     scoreCutoff, aligner] # rep = True; e-value cutoff is 10x more stringent than from ortho search
     otherCoreArgs = [cpus, debugCore, silentOff, noCleanup, force, append]
-    print('Compiling core set for %s' % seqName)
+    print('##### COMPILING CORE SET FOR %s #####' % seqName)
     core_runtime = core_fn.run_compile_core([seqFile, seqName, refspec, seed_id, reuseCore,
         forceCore, coreArgs, pathArgs, orthoCoreArgs, otherCoreArgs, debug])
     print('==> Core compilation finished in %s' % core_runtime[1])
@@ -230,6 +248,7 @@ def main():
     ##### DO ORTHOLOG SEARCH USING CORE HMM (HAMSTR)
     if not coreOnly:
         start = time.time()
+        print('##### SEARCHING ORTHOLOGS #####')
         # check existing output
         finalOutfile = '%s/%s.extended.fa' % (outpath, seqName)
         finalOutfile = os.path.abspath(finalOutfile)
@@ -265,6 +284,7 @@ def main():
 
         ##### DO FINAL FAS CALCULATION
         if not fasOff:
+            print('##### CALCULATING FAS SCORES #####')
             try:
                 fasVersion = subprocess.run(['fas.run --version'], shell = True, capture_output = True, check = True)
             except:
@@ -277,6 +297,14 @@ def main():
         else:
             output_fn.hamstr_2_profile(finalOutfile)
 
+        ##### ADD ALL SEARCH TAXA INTO PhyloProfile OUTPUT
+        if not notAddingTaxa:
+            pp_file = f'{outpath}/{seqName}.phyloprofile'
+            if not searchTaxa:
+                tmp = general_fn.read_dir(searchpath)
+                searchTaxa = ','.join(tmp)
+            output_fn.add_all_taxa(pp_file, searchTaxa)
+
         end = time.time()
         print('==> fdog.run finished in ' + '{:5.3f}s'.format(end - begin))
 
